# TestCaseRelationTypeDto


## Enum

* `RELATED_TO` (value: `'related to'`)

* `CLONES` (value: `'clones'`)

* `IS_CLONED_BY` (value: `'is cloned by'`)

* `DUPLICATES` (value: `'duplicates'`)

* `IS_DUPLICATED_BY` (value: `'is duplicated by'`)

* `AUTOMATES` (value: `'automates'`)

* `IS_AUTOMATED_BY` (value: `'is automated by'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


